#
# spec file for package torque
#
%define redhat_release %(cat /etc/redhat-release | cut -d\\( -f1 | sed 's/ [AWE]S //' | tr -cd '[A-Z0-9]' | tr '[A-Z]' '[a-z]')
# Default server name
%define default_server localhost
# Default binaries location (can be /usr)
#%define _pbs_home /opt/pbs
%define _pbs_home /usr
%define _pbs_spool /var/spool/pbs

Name:         torque
Version:      1.2.0p1
Release:      12%{redhat_release}
License:      Other License(s), see package
Summary:      Torque Portable Batch System
Group:        Productivity/Clustering/Computing
URL:          http://supercluster.org/torque
Source0:      http://www.clusterresources.com/downloads/torque/%{name}-%{version}.tar.gz
Source1:      torque-contrib-redhat.tar.gz
Patch0:       torque-AR.patch
Patch1:       torque-DESTDIR120.patch
Patch2:       torque-manpage-link.patch
Patch3:       torque-man7.patch
Provides:     pbs
Obsoletes:    pbs OpenPBS
BuildRoot:    %{_tmppath}/%{name}-%{version}-%{release}-build
Requires:     tcl tk

%description
The Portable Batch System (PBS) is a flexible batch software processing
system developed at NASA Ames Research Center. It operates on
networked, multi-platform UNIX environments, including heterogeneous
clusters of workstations, supercomputers, and massively parallel
systems.



Authors:
--------
    NASA Ames Research Center

%package server
Summary:      The Torque Server
Group:        Productivity/Clustering/Computing
Requires:     smtpdaemon
Requires:     %name = %version
PreReq:       /bin/chmod  /bin/rm

%description server
This package includes the files necessary for the batch server node.



Authors:
--------
    NASA Ames Research Cente

%package scheduler
Summary:      The Torque scheduler
Group:        Productivity/Clustering/Computing
Requires:     %name = %version

%description scheduler
Conflicts: %{name}_mom
The torque scheduler (pbs_sched) is a single daemon process that
evaluates jobs in the queues and selects those that will run next.



Authors:
--------
    NASA Ames Research Cente

%package mom
Summary:      Torque Execution host environment
Group:        Productivity/Clustering/Computing
requires: 	  openssh, %name = %version
Buildrequires: openssh
Conflicts: %{name}_scheduler %{name}_server

%description mom
This package is meant for an execution node. It does not include either
the scheduler or server.



Authors:
--------
    NASA Ames Research Cente

%package clients
Summary:      Portable Batch System - Clients
Group:        Productivity/Clustering/Computing
Requires:     %name = %version
PreReq:       /usr/bin/tclsh /bin/chmod  /bin/rm

%description clients
The Portable Batch System (PBS) is a flexible batch software processing
system developed at NASA Ames Research Center. It operates on
networked, multi-platform UNIX environments, including heterogeneous
clusters of workstations, supercomputers, and massively parallel
systems.

This Package includes all clients for queue administration and job
submission. To use these programs it is advised to install the package
environment-modules and load the pbs module which will set the path for
torque into your path.



Authors:
--------
    NASA Ames Research Center

%package devel
Summary:      Files required for development with torque
Group:        Productivity/Clustering/Computing
Requires:     %name = %version

%description devel
This package includes files needed for the development of software to
access torque data and functions.



Authors:
--------
    NASA Ames Research Cente

%package utils
Summary:      Portable Batch System - Utilities
Group:        Productivity/Clustering/Computing
Requires:     %name = %version
##Requires:     perl(Curses)

%description utils
This package contains various contributed utilities for queue
monitoring and other 3rd party utilities.



Authors:
--------
    NASA Ames Research Cente

%prep
%setup -q -n %{name}-%{version} -a 1

# Set pbstop to use locally set directory
cp contrib/pbstop contrib/pbstop.in
sed "s%/usr/local/pbs/bin%%{_pbs_home}/bin%g" contrib/pbstop.in > contrib/pbstop
chmod a+x contrib/pbstop

# Fix use of out-of-date @AR@ macros <nkadel@merl.com>
%patch0 -p1 -b .AR

# Restore use of DESTDIR <nkadel@merl.com>
%patch1 -p1 -b .DESTDIR

# Restore use of DESTDIR <nkadel@merl.com>
%patch2 -p1 -b .link

# Set up doc pages to put the man7 pages in their own directory,
# not hidden in the man1 directory
%patch3 -p1 -b .man7
mkdir -p doc/man7
/bin/mv doc/man1/*.7B doc/man7/.

# Rebuild configure, with old autoconf
# Use only if needed for RedHat use <nkadel@merl.com>
#autoconf
#autoreconf --force
#autoconf-2.13
#autoreconf-2.13 --force --install

# Set up docs, graphics, default locations, MOM, scheduler, and server
./configure --with-scp=/usr/bin/scp \
	--prefix=%{_pbs_home} \
	--libdir=%{_pbs_home}/%{_lib}/%{name} \
	--mandir=%{_pbs_home}/share/man \
	--enable-clients \
	--enable-docs \
	--with-tcl \
	--enable-tcl-qstat \
	--enable-syslog \
	--enable-gui \
	--x-libraries=/usr/X11R6/%{_lib} \
	--enable-mom \
	--set-sched=c \
	--enable-server \
		--set-server-home=%{_pbs_spool} \
		--set-server-name-file=%{_pbs_spool}/server    \
		--set-default-server=%{default_server}

%build
make

%install
rm -rf ${RPM_BUILD_ROOT}
RPM_BUILD_SPOOL=${RPM_BUILD_ROOT}%{_pbs_spool}

# Standard torque install
make DESTDIR=${RPM_BUILD_ROOT} install

# Set up default PBS servername config file (usually localhost)
mkdir -p ${RPM_BUILD_SPOOL}
install -m 644 contrib/redhat/config.server ${RPM_BUILD_SPOOL}/server

# Set up default scheduler configuration to get it under RPM
mkdir -p ${RPM_BUILD_SPOOL}
install -m 644 contrib/redhat/pbs_server.conf ${RPM_BUILD_SPOOL}/pbs_server.conf

# Set up empty nodes list to get it under RPM
mkdir -p ${RPM_BUILD_SPOOL}
install -m 644 contrib/redhat/nodes ${RPM_BUILD_SPOOL}/server_priv/nodes

# Make server_priv world-executable so that non-root users can get in
# to look at the accounting files
mkdir -p ${RPM_BUILD_SPOOL}/server_priv/jobs ${RPM_BUILD_SPOOL}/server_priv/queues
chmod 0751 ${RPM_BUILD_SPOOL}/server_priv
chmod 0751 ${RPM_BUILD_SPOOL}/server_priv/jobs
chmod 0751 ${RPM_BUILD_SPOOL}/server_priv/queues

# You probably want to install a more complete MOM configuration here!
# This is also an ideal place to copy custom server/scheduler configuration
# files from ${RPM_SOURCE_DIR} to ${RPM_BUILD_SPOOL}
mkdir -p ${RPM_BUILD_SPOOL}/mom_priv
chmod 0751 ${RPM_BUILD_SPOOL}/mom_priv
install -m 0644 contrib/redhat/config.mom_priv ${RPM_BUILD_SPOOL}/mom_priv/config

# Install init scripts for server, scheduler and MOM; we make the
# symlinks manually as chkconfig apparently doesn't understand chroot
mkdir -p ${RPM_BUILD_ROOT}/etc/rc.d/init.d
install -m 755 contrib/redhat/init.pbs_server $RPM_BUILD_ROOT/etc/rc.d/init.d/pbs_server
install -m 755 contrib/redhat/init.pbs_mom $RPM_BUILD_ROOT/etc/rc.d/init.d/pbs_mom
install -m 755 contrib/redhat/init.pbs_sched $RPM_BUILD_ROOT/etc/rc.d/init.d/pbs_sched

# Compress the manual pages, per RedHat standards <nkadel@merl.com>
gzip $RPM_BUILD_ROOT%{_pbs_home}/share/man/man*/*

# Install utilities, which do not have makefile <nkadel@merl.com>
install -m 755 contrib/qpeek $RPM_BUILD_ROOT%{_pbs_home}/bin/
install -m 755 contrib/redhat/qps $RPM_BUILD_ROOT%{_pbs_home}/bin

# Install latest pbstop from Garrick Staples
install -m 755 contrib/pbstop $RPM_BUILD_ROOT%{_pbs_home}/bin/

# Remove perl files just installed elsewhere to remove unnecessary dependencies
# in the base package, as base package includes the contrib directory
rm contrib/qpeek contrib/redhat/qps contrib/pbstop contrib/pbstop.in

%post
grep -q ^pbs /etc/services || echo "# Added pbs services for Torque software
pbs		15001/tcp		# pbs server (pbs_server)
pbs_mom		15002/tcp		# mom to/from server
pbs_resmom	15003/tcp		# mom resource management requests
pbs_resmom	15003/udp		# mom resource management requests
pbs_sched	15004/tcp		# scheduler" >> /etc/services

%post server
if [ "$1" = 1 ]; then
  /sbin/chkconfig --add pbs_server
  /sbin/chkconfig pbs_server on
else
  /sbin/chkconfig pbs_server reset
  /sbin/service pbs_server condrestart
fi

%postun server
if [ "$1" -ge "1" ]; then
    /sbin/service pbs_server condrestart >/dev/null 2>&1 || :
fi

%preun server
if [ "$1" = "0" ]; then
    /sbin/service pbs_server stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del pbs_server
fi

%post scheduler
if [ "$1" = 1 ]; then
  /sbin/chkconfig --add pbs_sched
  /sbin/chkconfig pbs_sched on
else
  /sbin/chkconfig pbs_sched reset
  /sbin/service pbs_sched condrestart
fi

%postun scheduler
if [ "$1" -ge "1" ]; then
    /sbin/service pbs_sched condrestart >/dev/null 2>&1 || :
fi

%preun scheduler
if [ "$1" = "0" ]; then
    /sbin/service pbs_sched stop >/dev/null || :
    /sbin/chkconfig --del pbs_sched
fi

%post mom
if [ "$1" = 1 ]; then
  /sbin/chkconfig --add pbs_mom
  /sbin/chkconfig pbs_mom on
else
  /sbin/chkconfig pbs_mom reset
  /sbin/service pbs_mom condrestart
fi

%postun mom
if [ "$1" -ge "1" ]; then
    /sbin/service pbs_mom condrestart >/dev/null 2>&1 || :
fi

%preun mom
if [ "$1" = "0" ]; then
    /sbin/service pbs_mom stop >/dev/null || :
    /sbin/chkconfig --del pbs_mom
fi

%post clients
# Build tcl indices for xpbsmon and xpbs (have to do this here as it uses
# absolute paths, and gets confused by a buildroot)
XPBSMON_LIB=%{_pbs_home}/%{_lib}/%{name}/xpbsmon
echo "Rebuilding tclIndex for xpbs programs"
rm -f ${XPBSMON_LIB}/tclIndex
cd ${XPBSMON_LIB} && ./buildindex ${XPBSMON_LIB} && chmod 644 tclIndex
XPBS_LIB=%{_pbs_home}/%{_lib}/%{name}/xpbs
rm -f ${XPBS_LIB}/tclIndex
cd ${XPBS_LIB} && ./buildindex ${XPBS_LIB} && chmod 644 tclIndex

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc README.torque
%doc contrib
%dir %{_pbs_spool}
#%dir /opt/pbs
%config(noreplace) %{_pbs_spool}/server
%dir %{_pbs_spool}/aux
%dir %{_pbs_spool}/spool
%dir %{_pbs_spool}/undelivered
%config(noreplace) %{_pbs_spool}/pbs_environment
%dir %{_pbs_home}/sbin
%dir %{_pbs_home}/bin
%dir %{_pbs_home}/%_lib/%{name}
%attr(4755, root,root) %{_pbs_home}/sbin/pbs_iff
#%dir %{_pbs_home}/share/man
%dir %{_pbs_home}/share/man/man1
%dir %{_pbs_home}/share/man/man8
%dir %{_pbs_home}/share/man/man7
%doc %{_pbs_home}/share/man/man1/pbs.1B.gz
%doc CHANGELOG INSTALL PBS_License.txt README.mpiexec README.torque Release_Notes
%doc doc/admin_guide.ps doc/doc_fonts

%files server
%defattr(-,root,root)
%doc %{_pbs_home}/share/man/man8/qterm.8B.gz
%doc %{_pbs_home}/share/man/man8/pbs_server.8B.gz
%{_pbs_home}/sbin/pbs_server
%dir %{_pbs_spool}/server_logs
%dir %{_pbs_spool}/server_priv
%config(noreplace) %{_pbs_spool}/server
%{_pbs_spool}/server_priv/accounting
%{_pbs_spool}/server_priv/acl_groups
%{_pbs_spool}/server_priv/acl_hosts
%{_pbs_spool}/server_priv/acl_svr
%{_pbs_spool}/server_priv/acl_users
%{_pbs_spool}/server_priv/jobs
%{_pbs_spool}/server_priv/queues
%{_pbs_home}/bin/qterm
%config(noreplace) %{_pbs_spool}/server_priv/nodes
/etc/rc.d/init.d/pbs_server

%files scheduler
%defattr(-,root,root)
%{_pbs_home}/sbin/pbs_sched
%dir %{_pbs_spool}/sched_logs
%dir %{_pbs_spool}/sched_priv
%config(noreplace) %{_pbs_spool}/sched_priv/sched_config
%config(noreplace) %{_pbs_spool}/sched_priv/resource_group
%config(noreplace) %{_pbs_spool}/sched_priv/holidays
%config(noreplace) %{_pbs_spool}/sched_priv/dedicated_time
%config(noreplace) %{_pbs_spool}/pbs_server.conf
%doc %{_pbs_home}/share/man/man1/basl2c.1B.gz
%doc %{_pbs_home}/share/man/man8/pbs_sched_cc.8B.gz
%doc %{_pbs_home}/share/man/man8/pbs_sched_basl.8B.gz
%doc %{_pbs_home}/share/man/man8/pbs_sched_tcl.8B.gz
/etc/rc.d/init.d/pbs_sched

%files utils
%defattr(-,root,root)
%{_pbs_home}/bin/pbstop
%{_pbs_home}/bin/qpeek
%{_pbs_home}/bin/qps

%files mom
%defattr(-,root,root)
%{_pbs_home}/sbin/pbs_mom
%{_pbs_home}/sbin/pbs_rcp
%{_pbs_home}/sbin/pbs_demux
%{_pbs_home}/bin/pbsdsh
%{_pbs_spool}/checkpoint
%dir %{_pbs_spool}/mom_logs
%dir %{_pbs_spool}/mom_priv
%dir %{_pbs_spool}/mom_priv/jobs
%config(noreplace) %{_pbs_spool}/mom_priv/config
%doc %{_pbs_home}/share/man/man8/pbs_mom.8B.gz
%doc %{_pbs_home}/share/man/man1/pbsdsh.1B.gz
/etc/rc.d/init.d/pbs_mom

%files clients
%defattr(-,root,root)
%{_pbs_home}/bin/chk_tree
%{_pbs_home}/bin/hostn
%{_pbs_home}/bin/printjob
%{_pbs_home}/bin/nqs2pbs
%{_pbs_home}/bin/qalter
%{_pbs_home}/bin/qdel
%{_pbs_home}/bin/qhold
%{_pbs_home}/bin/qmove
%{_pbs_home}/bin/qorder
%{_pbs_home}/bin/qmsg
%{_pbs_home}/bin/qrerun
%{_pbs_home}/bin/qrls
%{_pbs_home}/bin/qselect
%{_pbs_home}/bin/qsig
%{_pbs_home}/bin/qstat
%{_pbs_home}/bin/qsub
%{_pbs_home}/bin/qdisable
%{_pbs_home}/bin/qenable
%{_pbs_home}/bin/qrun
%{_pbs_home}/bin/qstart
%{_pbs_home}/bin/qstop
%{_pbs_home}/bin/pbsnodes
%{_pbs_home}/bin/qmgr
%{_pbs_home}/bin/xpbs
%{_pbs_home}/bin/xpbsmon
%{_pbs_home}/%{_lib}/%{name}/xpbs
%{_pbs_home}/%{_lib}/%{name}/xpbsmon
%{_pbs_home}/bin/pbs_wish
%{_pbs_home}/bin/pbs_tclsh
%{_pbs_home}/bin/tracejob
%{_pbs_home}/sbin/momctl
%doc %{_pbs_home}/share/man/man1/qalter.1B.gz
%doc %{_pbs_home}/share/man/man1/qdel.1B.gz
%doc %{_pbs_home}/share/man/man1/qhold.1B.gz
%doc %{_pbs_home}/share/man/man1/qmove.1B.gz
%doc %{_pbs_home}/share/man/man1/qmsg.1B.gz
%doc %{_pbs_home}/share/man/man1/qorder.1B.gz
%doc %{_pbs_home}/share/man/man1/qrerun.1B.gz
%doc %{_pbs_home}/share/man/man1/qrls.1B.gz
%doc %{_pbs_home}/share/man/man1/qselect.1B.gz
%doc %{_pbs_home}/share/man/man1/qsig.1B.gz
%doc %{_pbs_home}/share/man/man1/qstat.1B.gz
%doc %{_pbs_home}/share/man/man1/qsub.1B.gz
%doc %{_pbs_home}/share/man/man1/xpbs.1B.gz
%doc %{_pbs_home}/share/man/man1/xpbsmon.1B.gz
%doc %{_pbs_home}/share/man/man1/nqs2pbs.1B.gz
%doc %{_pbs_home}/share/man/man8/qdisable.8B.gz
%doc %{_pbs_home}/share/man/man8/qenable.8B.gz
%doc %{_pbs_home}/share/man/man8/qmgr.8B.gz
%doc %{_pbs_home}/share/man/man8/qrun.8B.gz
%doc %{_pbs_home}/share/man/man8/qstart.8B.gz
%doc %{_pbs_home}/share/man/man8/qstop.8B.gz
%doc %{_pbs_home}/share/man/man8/pbsnodes.8B.gz
%doc %{_pbs_home}/share/man/man7/pbs_job_attributes.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_queue_attributes.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_server_attributes.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_all.soB.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_aix4.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_digitalunix.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_freebsd.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_fujitsu.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_irix5.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_irix6array.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_irix6.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_linux.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_netbsd.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_solaris5.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_solaris7.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_sp2.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_sunos4.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_unicos8.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources_unicosmk2.7B.gz
%doc %{_pbs_home}/share/man/man7/pbs_resources.7B.gz

%files devel
%defattr(-,root,root)
%{_pbs_home}/%_lib/%{name}/*.a
%dir %{_pbs_home}/include
%dir %{_pbs_home}/share/man/man3
%{_pbs_home}/include/*
%doc %{_pbs_home}/share/man/man3/*

%changelog -n torque
* Thu Mar 03 2005 - Lawrence Lowe <L.S.Lowe@bham.ac.uk>
- Update to 1.2.0p1
- list of docs to copy out of the base directory needed changing
* Wed Oct 20 2004 - Lawrence Lowe <L.S.Lowe@bham.ac.uk>
- Update to 1.1.0p4
- Tweak the way redhat_release is computed to be RHEL/WBEL/SL compatible.
- Remove files from contrib directory which are 'install'ed elsewhere
* Tue Oct 19 2004 - Lawrence Lowe <L.S.Lowe@bham.ac.uk>
- Update to 1.1.0p3
- Fix an error in some %postun scripts ";" -> ":"
- Add %post scripts to do chkconfig --add
- Comment out perl(Curses) dependency, as it fails, for me.
* Mon Oct 11 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Add pbs_server.conf to default configurations

* Thu Oct  7 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Update to 1.1.0p2
- Use up-to-date pbstop in tarball
- Move torque libs into subdirectory to avoid conflict with libattr.a

* Wed Sep 29 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Eliminate pbs.modules source, no longer used
- Add latest version of pbstop
- Add $1 handling to %post scripting
- Add pbs /etc/services entries to %post installation

* Sun Sep 26 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Re-arrange order of init scripts to sched/server/mom

* Sun Sep 19 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Add perl(Curses) requirement for the utils package
- Move manual pages back to $PBS_HOME/share/man to $PBS_HOME/man
- Set "default_server" config file back to "server" as manpages describe
- Update init scripts to not rely on /etc/sysconfig SuSE settings
- Move RedHat style contributed widgets to their own location
- Move pbs_home to /usr, like most RedHat system tools
- Add blank pbs_spool/server_priv/nodes file and check for it at init time
- Set all local config files to be (noreplace)
- Set up pbs_server init script to check and create serverdb if needed
- Include all man3/* pages as development docs

* Fri Sep 17 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Straighten out man1/*.7B doc manpages to simply be man7/*.
- Move manual pages from $PBS_HOME/man to $PBS_HOME/share/man.
- Set all man pages to be %doc.

* Thu Sep 16 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Update to 1.1.0p1
- Rip out /usr/sbin/rcpb* symbolic links, use /sbin/service instead
- Rip out "modulefiles"
- Rip out "preferences"
- Add "--enable-gui" since xpbs is no longer built by default
- Fold in old SuSE pbstop and qps utilities to contrib directory
- Fold in old SuSE qmgr.cfg to contrib directory

* Sun Sep 12 2004 - Nico Kadel-Garcia <nkadel@merl.com>
- Create initial spec file from old Suse OpenPBS.spec
- Document autoconf step at setup time
- Edit out AC_PROG_AR, old autoconf macro no longer supported
- Edit back in use of $(DESTDIR) variable for make install stage
- Compress manual pages in install process
- Replace use of hard linked man pages with ".so" syntax pages
- Add rpp.h include file to devel package
- Remove "environment modules" dependency
- Rename smtp_daemon requirement to smtpdaemon
- Write in conflicts between mom and server/scheduler
- Replace old SuSE init files with RedHat compatible init files
- Replace old SuSE SuseConfig.pbs weirdness with actual config files
